#ifndef _CHAMPLAIN_PERL_H_

#include <clutter-perl.h>

#include <champlain/champlain.h>

#include "champlain-autogen.h"

#endif /* _CHAMPLAIN_PERL_H_ */
